==> p5-DBD-Oracle-1.12.tgz: lib/perl5/site_perl/5.005/i386-freebsd/auto/DBD/Oracle/mk.pm <==
$dbd_oracle_mm_opts = {
                        'NAME' => 'DBD::Oracle',
                        'AUTHOR' => 'Tim Bunce (dbi-users@perl.org)',
                        'clean' => {
                                     'FILES' => 'Oracle.xsi dll.base dll.exp sqlnet.log libOracle.def ora_explain mk.pm'
                                   },
                        'dist' => {
                                    'DIST_DEFAULT' => 'clean distcheck disttest ci tardist',
                                    'COMPRESS' => 'gzip -v9',
                                    'SUFFIX' => 'gz',
                                    'PREOP' => '$(MAKE) -f Makefile.old distdir'
                                  },
                        'EXE_FILES' => [
                                         'ora_explain'
                                       ],
                        'ABSTRACT_FROM' => 'Oracle.pm',
                        'OBJECT' => '$(O_FILES)',
                        'VERSION_FROM' => 'Oracle.pm',
                        'INC' => '-I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/public -I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/demo -I/usr/local/lib/perl5/site_perl/5.005/i386-freebsd/auto/DBI',
                        'DEFINE' => '',
                        'PREREQ_PM' => {
                                         'DBI' => '0'
                                       },
                        'dynamic_lib' => {
                                           'OTHERLDFLAGS' => ' -L/usr/local/oracle7/lib -L/usr/local/oracle7/rdbms/lib   /usr/local/oracle7/lib/libclient.a -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric /usr/local/oracle7/rdbms/lib/libstublm.a -lld -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric /usr/local/oracle7/rdbms/lib/libstublm.a -lld -lepc -lnlsrtl3 -lc3v6 -lcore3 -lwrap -lnlsrtl3 -lcore3 -lwrap -lnlsrtl3 -lm -lcore3 -lwrap'
                                         },
                        'DIR' => []
                      };
$dbd_oracle_mm_self = bless( {
                               'SO' => 'so',
                               'OSVERS' => '4.0-current',
                               'MAP_TARGET' => 'perl',
                               'FULLEXT' => 'DBD/Oracle',
                               'INSTALLMAN3DIR' => '/usr/local/lib/perl5/5.00503/man/man3',
                               'VERSION' => '1.12',
                               'INSTALLDIRS' => 'site',
                               'CHMOD' => 'chmod',
                               'OBJ_EXT' => '.o',
                               'INST_MAN3DIR' => 'blib/man3',
                               'DLBASE' => '$(BASEEXT)',
                               'PERL_INC' => '/usr/libdata/perl/5.00503/mach/CORE',
                               'INSTALLARCHLIB' => '/usr/local/lib',
                               'BOOTDEP' => '',
                               'LD' => 'cc',
                               'INST_SCRIPT' => 'blib/script',
                               'INST_ARCHLIB' => 'blib/arch',
                               'DISTNAME' => 'DBD-Oracle',
                               'SITELIBEXP' => '/usr/local/lib/perl5/site_perl/5.005',
                               'NAME_SYM' => 'DBD_Oracle',
                               'PERL_SRC' => undef,
                               'LIBC' => '',
                               'dynamic_lib' => $dbd_oracle_mm_opts->{'dynamic_lib'},
                               'NOECHO' => '@',
                               'NOOP' => '$(SHELL) -c true',
                               'PM' => {
                                         'Oraperl.pm' => '$(INST_LIB)/Oraperl.pm',
                                         'Oracle.pm' => '$(INST_LIBDIR)/Oracle.pm',
                                         'oraperl.ph' => '$(INST_LIB)/oraperl.ph',
                                         'mk.pm' => '$(INST_LIBDIR)/mk.pm'
                                       },
                               'LDFLAGS' => '-Wl,-E -lperl -lm ',
                               'INST_EXE' => 'blib/script',
                               'RM_F' => 'rm -f',
                               'PMLIBDIRS' => [],
                               'AR_STATIC_ARGS' => 'cr',
                               'LIB_EXT' => '.a',
                               'ABSTRACT_FROM' => 'Oracle.pm',
                               'PERL_LIB' => '/usr/libdata/perl/5.00503',
                               'LIBS' => [
                                           ''
                                         ],
                               'LIBPERL_A' => 'libperl.a',
                               'XS' => {
                                         'Oracle.xs' => 'Oracle.c'
                                       },
                               'PREREQ_PM' => $dbd_oracle_mm_opts->{'PREREQ_PM'},
                               'LDDLFLAGS' => '-Wl,-E -shared -lperl -lm ',
                               'INSTALLPRIVLIB' => '/usr/local/lib',
                               'LINKTYPE' => 'dynamic',
                               'XS_VERSION' => '1.12',
                               'PERL' => '/usr/bin/perl5.00503',
                               'AR' => 'ar',
                               'CCFLAGS' => '-O -pipe ',
                               'INST_AUTODIR' => '$(INST_LIB)/auto/$(FULLEXT)',
                               'UMASK_NULL' => 'umask 0',
                               'MAKEFILE' => 'Makefile',
                               'MAN3EXT' => 3,
                               'SITEARCHEXP' => '/usr/local/lib/perl5/site_perl/5.005/i386-freebsd',
                               'O_FILES' => [
                                              'Oracle.o',
                                              'dbdimp.o',
                                              'oci7.o',
                                              'oci8.o'
                                            ],
                               'NAME' => 'DBD::Oracle',
                               'DLEXT' => 'so',
                               'MV' => 'mv',
                               'TOUCH' => 'touch',
                               'C' => [
                                        'Oracle.c',
                                        'dbdimp.c',
                                        'oci7.c',
                                        'oci8.c'
                                      ],
                               'INSTALLMAN1DIR' => '/usr/local/man/man1',
                               'CCDLFLAGS' => ' -Wl,-R/usr/lib',
                               'OSNAME' => 'freebsd',
                               'PERL_ARCHLIB' => '/usr/libdata/perl/5.00503/mach',
                               'H' => [
                                        'Oracle.h',
                                        'dbdimp.h',
                                        'ocitrace.h'
                                      ],
                               'INST_MAN1DIR' => 'blib/man1',
                               'INSTALLSITEARCH' => '/usr/local/lib/perl5/site_perl/5.005/i386-freebsd',
                               'BASEEXT' => 'Oracle',
                               'INSTALLSCRIPT' => '$(PREFIX)/bin',
                               'PL_FILES' => {
                                               'ora_explain.PL' => 'ora_explain'
                                             },
                               'PREFIX' => '/usr/local',
                               'INST_ARCHLIBDIR' => '$(INST_ARCHLIB)/DBD',
                               'EXE_EXT' => '',
                               'AUTHOR' => 'Tim Bunce (dbi-users@perl.org)',
                               'INST_ARCHAUTODIR' => '$(INST_ARCHLIB)/auto/$(FULLEXT)',
                               'EXE_FILES' => $dbd_oracle_mm_opts->{'EXE_FILES'},
                               'dist' => $dbd_oracle_mm_opts->{'dist'},
                               'RANLIB' => ':',
                               'INC' => '-I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/public -I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/demo -I/usr/local/lib/perl5/site_perl/5.005/i386-freebsd/auto/DBI',
                               'VERSION_SYM' => '1_12',
                               'MAN1PODS' => {
                                               'ora_explain' => '$(INST_MAN1DIR)/ora_explain.$(MAN1EXT)'
                                             },
                               'clean' => $dbd_oracle_mm_opts->{'clean'},
                               'INSTALLSITELIB' => '/usr/local/lib/perl5/site_perl/5.005',
                               'LDFROM' => '$(OBJECT)',
                               'TEST_F' => 'test -f',
                               'FIRST_MAKEFILE' => 'Makefile',
                               'MAN3PODS' => {
                                               'Oraperl.pm' => '$(INST_MAN3DIR)/DBD::Oraperl.$(MAN3EXT)',
                                               'Oracle.pm' => '$(INST_MAN3DIR)/DBD::Oracle.$(MAN3EXT)'
                                             },
                               'FULLPERL' => '/usr/bin/perl5.00503',
                               'CC' => 'cc',
                               'CCCDLFLAGS' => '-DPIC -fpic',
                               'PARENT_NAME' => 'DBD',
                               'DEFINE' => '',
                               'MAKE_APERL_FILE' => 'Makefile.aperl',
                               'LD_RUN_PATH' => '',
                               'INSTALLBIN' => '$(PREFIX)/bin',
                               'CP' => 'cp',
                               'INST_LIBDIR' => '$(INST_LIB)/DBD',
                               'INST_LIB' => 'blib/lib',
                               'RM_RF' => 'rm -rf',
                               'INST_BIN' => 'blib/bin',
                               'CONFIG' => [
                                             'ar',
                                             'cc',
                                             'cccdlflags',
                                             'ccdlflags',
                                             'dlext',
                                             'dlsrc',
                                             'ld',
                                             'lddlflags',
                                             'ldflags',
                                             'libc',
                                             'lib_ext',
                                             'obj_ext',
                                             'osname',
                                             'osvers',
                                             'ranlib',
                                             'sitelibexp',
                                             'sitearchexp',
                                             'so',
                                             'exe_ext'
                                           ],
                               'OBJECT' => '$(O_FILES)',
                               'DLSRC' => 'dl_dlopen.xs',
                               'DEV_NULL' => '> /dev/null 2>&1',
                               'VERSION_FROM' => 'Oracle.pm',
                               'SKIPHASH' => {},
                               'PERLMAINCC' => '$(CC)',
                               'MAN1EXT' => 1,
                               'RESULT' => [
                                             '# This Makefile is for the DBD::Oracle extension to perl.
#
# It was generated automatically by MakeMaker version
# 5.4302 (Revision: 1.222) from the contents of
# Makefile.PL. Don\'t edit this file, edit Makefile.PL instead.
#
#	ANY CHANGES MADE HERE WILL BE LOST!
#
#   MakeMaker ARGV: (q[CC=cc], q[CCFLAGS=-O -pipe ], q[PREFIX=/usr/local], q[INSTALLPRIVLIB=/usr/local/lib], q[INSTALLARCHLIB=/usr/local/lib])
#
#   MakeMaker Parameters:
',
                                             '#	ABSTRACT_FROM => q[Oracle.pm]',
                                             '#	AUTHOR => q[Tim Bunce (dbi-users@perl.org)]',
                                             '#	DEFINE => q[]',
                                             '#	DIR => []',
                                             '#	EXE_FILES => [q[ora_explain]]',
                                             '#	INC => q[-I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/public -I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/demo -I/usr/local/lib/perl5/site_perl/5.005/i386-freebsd/auto/DBI]',
                                             '#	NAME => q[DBD::Oracle]',
                                             '#	OBJECT => q[$(O_FILES)]',
                                             '#	PREREQ_PM => { DBI=>q[0] }',
                                             '#	VERSION_FROM => q[Oracle.pm]',
                                             '#	clean => { FILES=>q[Oracle.xsi dll.base dll.exp sqlnet.log libOracle.def ora_explain mk.pm] }',
                                             '#	dist => { DIST_DEFAULT=>q[clean distcheck disttest ci tardist], COMPRESS=>q[gzip -v9], SUFFIX=>q[gz], PREOP=>q[$(MAKE) -f Makefile.old distdir] }',
                                             '#	dynamic_lib => { OTHERLDFLAGS=>q[ -L/usr/local/oracle7/lib -L/usr/local/oracle7/rdbms/lib   /usr/local/oracle7/lib/libclient.a -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric /usr/local/oracle7/rdbms/lib/libstublm.a -lld -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric /usr/local/oracle7/rdbms/lib/libstublm.a -lld -lepc -lnlsrtl3 -lc3v6 -lcore3 -lwrap -lnlsrtl3 -lcore3 -lwrap -lnlsrtl3 -lm -lcore3 -lwrap] }',
                                             '
# --- MakeMaker post_initialize section:'
                                           ],
                               'DIR' => $dbd_oracle_mm_opts->{'DIR'}
                             }, 'PACK001' );

==> p5-DBD-Oracle-1.14.tgz: lib/perl5/site_perl/5.005/i386-freebsd/auto/DBD/Oracle/mk.pm <==
$dbd_oracle_mm_opts = {
                        'NAME' => 'DBD::Oracle',
                        'AUTHOR' => 'Tim Bunce (dbi-users@perl.org)',
                        'clean' => {
                                     'FILES' => 'Oracle.xsi dll.base dll.exp sqlnet.log libOracle.def ora_explain mk.pm'
                                   },
                        'dist' => {
                                    'DIST_DEFAULT' => 'clean distcheck disttest ci tardist',
                                    'COMPRESS' => 'gzip -v9',
                                    'SUFFIX' => 'gz',
                                    'PREOP' => '$(MAKE) -f Makefile.old distdir'
                                  },
                        'EXE_FILES' => [
                                         'ora_explain'
                                       ],
                        'ABSTRACT_FROM' => 'Oracle.pm',
                        'OBJECT' => '$(O_FILES)',
                        'VERSION_FROM' => 'Oracle.pm',
                        'INC' => '-I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/public -I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/demo -I/usr/local/lib/perl5/site_perl/5.005/i386-freebsd/auto/DBI',
                        'LIBS' => [
                                    '-L/usr/local/oracle7/lib -L/usr/local/oracle7/lib -lclient -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric -L/usr/local/oracle7/rdbms/lib -lstublm -lld -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric -L/usr/local/oracle7/rdbms/lib -lstublm -lld -lepc -lnlsrtl3 -lc3v6 -lcore3 -lwrap -lnlsrtl3 -lcore3 -lwrap -lnlsrtl3 -lm -lcore3 -lwrap'
                                  ],
                        'dynamic_lib' => {
                                           'OTHERLDFLAGS' => '  $(COMPOBJS)'
                                         },
                        'DEFINE' => '',
                        'PREREQ_PM' => {
                                         'DBI' => '0'
                                       },
                        'DIR' => []
                      };
$dbd_oracle_mm_self = bless( {
                               'SO' => 'so',
                               'OSVERS' => '4.0-current',
                               'MAP_TARGET' => 'perl',
                               'FULLEXT' => 'DBD/Oracle',
                               'INSTALLMAN3DIR' => '/usr/local/lib/perl5/5.00503/man/man3',
                               'VERSION' => '1.14',
                               'INSTALLDIRS' => 'site',
                               'CHMOD' => 'chmod',
                               'OBJ_EXT' => '.o',
                               'INST_MAN3DIR' => 'blib/man3',
                               'DLBASE' => '$(BASEEXT)',
                               'PERL_INC' => '/usr/libdata/perl/5.00503/mach/CORE',
                               'INSTALLARCHLIB' => '/usr/local/lib',
                               'BOOTDEP' => '',
                               'LD' => 'cc',
                               'INST_SCRIPT' => 'blib/script',
                               'INST_ARCHLIB' => 'blib/arch',
                               'DISTNAME' => 'DBD-Oracle',
                               'SITELIBEXP' => '/usr/local/lib/perl5/site_perl/5.005',
                               'NAME_SYM' => 'DBD_Oracle',
                               'PERL_SRC' => undef,
                               'LIBC' => '',
                               'dynamic_lib' => $dbd_oracle_mm_opts->{'dynamic_lib'},
                               'NOECHO' => '@',
                               'NOOP' => '$(SHELL) -c true',
                               'PM' => {
                                         'Oraperl.pm' => '$(INST_LIB)/Oraperl.pm',
                                         'Oracle.pm' => '$(INST_LIBDIR)/Oracle.pm',
                                         'oraperl.ph' => '$(INST_LIB)/oraperl.ph',
                                         'lib/DBD/Oracle/GetInfo.pm' => '$(INST_LIB)/DBD/Oracle/GetInfo.pm',
                                         'mk.pm' => '$(INST_LIBDIR)/mk.pm'
                                       },
                               'LDFLAGS' => '-Wl,-E -lperl -lm ',
                               'INST_EXE' => 'blib/script',
                               'RM_F' => 'rm -f',
                               'PMLIBDIRS' => [
                                                'lib'
                                              ],
                               'AR_STATIC_ARGS' => 'cr',
                               'LIB_EXT' => '.a',
                               'ABSTRACT_FROM' => 'Oracle.pm',
                               'PERL_LIB' => '/usr/libdata/perl/5.00503',
                               'LIBPERL_A' => 'libperl.a',
                               'LIBS' => $dbd_oracle_mm_opts->{'LIBS'},
                               'XS' => {
                                         'Oracle.xs' => 'Oracle.c'
                                       },
                               'PREREQ_PM' => $dbd_oracle_mm_opts->{'PREREQ_PM'},
                               'LDDLFLAGS' => '-Wl,-E -shared -lperl -lm ',
                               'INSTALLPRIVLIB' => '/usr/local/lib',
                               'LINKTYPE' => 'dynamic',
                               'XS_VERSION' => '1.14',
                               'PERL' => '/usr/bin/perl5.00503',
                               'AR' => 'ar',
                               'CCFLAGS' => '-O -pipe ',
                               'INST_AUTODIR' => '$(INST_LIB)/auto/$(FULLEXT)',
                               'LDLOADLIBS' => '-L/usr/local/oracle7/lib -L/usr/local/oracle7/lib -lclient -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric -L/usr/local/oracle7/rdbms/lib -lstublm -lld -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric -L/usr/local/oracle7/rdbms/lib -lstublm -lld -lepc -lnlsrtl3 -lc3v6 -lcore3 -lwrap -lnlsrtl3 -lcore3 -lwrap -lnlsrtl3 -lm -lcore3 -lwrap',
                               'UMASK_NULL' => 'umask 0',
                               'MAKEFILE' => 'Makefile',
                               'MAN3EXT' => 3,
                               'SITEARCHEXP' => '/usr/local/lib/perl5/site_perl/5.005/i386-freebsd',
                               'O_FILES' => [
                                              'Oracle.o',
                                              'dbdimp.o',
                                              'oci7.o',
                                              'oci8.o'
                                            ],
                               'NAME' => 'DBD::Oracle',
                               'DLEXT' => 'so',
                               'MV' => 'mv',
                               'TOUCH' => 'touch',
                               'C' => [
                                        'Oracle.c',
                                        'dbdimp.c',
                                        'oci7.c',
                                        'oci8.c'
                                      ],
                               'INSTALLMAN1DIR' => '/usr/local/man/man1',
                               'CCDLFLAGS' => ' -Wl,-R/usr/lib',
                               'OSNAME' => 'freebsd',
                               'PERL_ARCHLIB' => '/usr/libdata/perl/5.00503/mach',
                               'H' => [
                                        'Oracle.h',
                                        'dbdimp.h',
                                        'ocitrace.h'
                                      ],
                               'INST_MAN1DIR' => 'blib/man1',
                               'INSTALLSITEARCH' => '/usr/local/lib/perl5/site_perl/5.005/i386-freebsd',
                               'BASEEXT' => 'Oracle',
                               'INSTALLSCRIPT' => '$(PREFIX)/bin',
                               'PL_FILES' => {
                                               'ora_explain.PL' => 'ora_explain'
                                             },
                               'PREFIX' => '/usr/local',
                               'INST_ARCHLIBDIR' => '$(INST_ARCHLIB)/DBD',
                               'EXE_EXT' => '',
                               'AUTHOR' => 'Tim Bunce (dbi-users@perl.org)',
                               'INST_ARCHAUTODIR' => '$(INST_ARCHLIB)/auto/$(FULLEXT)',
                               'EXE_FILES' => $dbd_oracle_mm_opts->{'EXE_FILES'},
                               'dist' => $dbd_oracle_mm_opts->{'dist'},
                               'RANLIB' => ':',
                               'INC' => '-I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/public -I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/demo -I/usr/local/lib/perl5/site_perl/5.005/i386-freebsd/auto/DBI',
                               'VERSION_SYM' => '1_14',
                               'MAN1PODS' => {
                                               'ora_explain' => '$(INST_MAN1DIR)/ora_explain.$(MAN1EXT)'
                                             },
                               'clean' => $dbd_oracle_mm_opts->{'clean'},
                               'INSTALLSITELIB' => '/usr/local/lib/perl5/site_perl/5.005',
                               'LDFROM' => '$(OBJECT)',
                               'TEST_F' => 'test -f',
                               'FIRST_MAKEFILE' => 'Makefile',
                               'MAN3PODS' => {
                                               'Oraperl.pm' => '$(INST_MAN3DIR)/DBD::Oraperl.$(MAN3EXT)',
                                               'Oracle.pm' => '$(INST_MAN3DIR)/DBD::Oracle.$(MAN3EXT)'
                                             },
                               'FULLPERL' => '/usr/bin/perl5.00503',
                               'CC' => 'cc',
                               'CCCDLFLAGS' => '-DPIC -fpic',
                               'PARENT_NAME' => 'DBD',
                               'DEFINE' => '',
                               'EXTRALIBS' => '-L/usr/local/oracle7/lib -L/usr/local/oracle7/lib -lclient -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric -L/usr/local/oracle7/rdbms/lib -lstublm -lld -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric -L/usr/local/oracle7/rdbms/lib -lstublm -lld -lepc -lnlsrtl3 -lc3v6 -lcore3 -lwrap -lnlsrtl3 -lcore3 -lwrap -lnlsrtl3 -lm -lcore3 -lwrap',
                               'MAKE_APERL_FILE' => 'Makefile.aperl',
                               'LD_RUN_PATH' => '/usr/local/oracle7/lib:/usr/lib',
                               'INSTALLBIN' => '$(PREFIX)/bin',
                               'CP' => 'cp',
                               'INST_LIBDIR' => '$(INST_LIB)/DBD',
                               'INST_LIB' => 'blib/lib',
                               'RM_RF' => 'rm -rf',
                               'INST_BIN' => 'blib/bin',
                               'CONFIG' => [
                                             'ar',
                                             'cc',
                                             'cccdlflags',
                                             'ccdlflags',
                                             'dlext',
                                             'dlsrc',
                                             'ld',
                                             'lddlflags',
                                             'ldflags',
                                             'libc',
                                             'lib_ext',
                                             'obj_ext',
                                             'osname',
                                             'osvers',
                                             'ranlib',
                                             'sitelibexp',
                                             'sitearchexp',
                                             'so',
                                             'exe_ext'
                                           ],
                               'OBJECT' => '$(O_FILES)',
                               'DLSRC' => 'dl_dlopen.xs',
                               'DEV_NULL' => '> /dev/null 2>&1',
                               'VERSION_FROM' => 'Oracle.pm',
                               'SKIPHASH' => {},
                               'PERLMAINCC' => '$(CC)',
                               'MAN1EXT' => 1,
                               'RESULT' => [
                                             '# This Makefile is for the DBD::Oracle extension to perl.
#
# It was generated automatically by MakeMaker version
# 5.4302 (Revision: 1.222) from the contents of
# Makefile.PL. Don\'t edit this file, edit Makefile.PL instead.
#
#	ANY CHANGES MADE HERE WILL BE LOST!
#
#   MakeMaker ARGV: (q[CC=cc], q[CCFLAGS=-O -pipe ], q[PREFIX=/usr/local], q[INSTALLPRIVLIB=/usr/local/lib], q[INSTALLARCHLIB=/usr/local/lib])
#
#   MakeMaker Parameters:
',
                                             '#	ABSTRACT_FROM => q[Oracle.pm]',
                                             '#	AUTHOR => q[Tim Bunce (dbi-users@perl.org)]',
                                             '#	DEFINE => q[]',
                                             '#	DIR => []',
                                             '#	EXE_FILES => [q[ora_explain]]',
                                             '#	INC => q[-I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/public -I/usr/local/oracle7/rdbms/demo -I/usr/local/oracle7/rdbms/demo -I/usr/local/lib/perl5/site_perl/5.005/i386-freebsd/auto/DBI]',
                                             '#	LIBS => [q[-L/usr/local/oracle7/lib -L/usr/local/oracle7/lib -lclient -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric -L/usr/local/oracle7/rdbms/lib -lstublm -lld -lsqlnet -lncr -lsqlnet -lclient -lcommon -lgeneric -L/usr/local/oracle7/rdbms/lib -lstublm -lld -lepc -lnlsrtl3 -lc3v6 -lcore3 -lwrap -lnlsrtl3 -lcore3 -lwrap -lnlsrtl3 -lm -lcore3 -lwrap]]',
                                             '#	NAME => q[DBD::Oracle]',
                                             '#	OBJECT => q[$(O_FILES)]',
                                             '#	PREREQ_PM => { DBI=>q[0] }',
                                             '#	VERSION_FROM => q[Oracle.pm]',
                                             '#	clean => { FILES=>q[Oracle.xsi dll.base dll.exp sqlnet.log libOracle.def ora_explain mk.pm] }',
                                             '#	dist => { DIST_DEFAULT=>q[clean distcheck disttest ci tardist], COMPRESS=>q[gzip -v9], SUFFIX=>q[gz], PREOP=>q[$(MAKE) -f Makefile.old distdir] }',
                                             '#	dynamic_lib => { OTHERLDFLAGS=>q[  $(COMPOBJS)] }',
                                             '
# --- MakeMaker post_initialize section:'
                                           ],
                               'BSLOADLIBS' => '',
                               'DIR' => $dbd_oracle_mm_opts->{'DIR'}
                             }, 'PACK001' );
